require 'base64'

module CaptchaSolver
  class RecaptchaV1 < Base
    attr_reader :image_path, :help_params

    def initialize(args)
      super
      @image_path = args[:image_path]
      @help_params = args[:help_params]
    end

    private

    def phrase
      help_params[:phrase] == true ? 1 : 0
    end

    def register_sensitive
      help_params[:register_sensitive] == true ? 1 : 0
    end

    def numeric
      return 0 unless help_params.key?(:numeric)
      {
        digits: 1,
        letters: 2,
        digits_or_letters: 3,
        digits_and_letters: 4
      }[help_params[:numeric]] || 0
    end

    def calculation
      help_params[:calculation] == true ? 1 : 0
    end

    def language
      return 0 unless help_params.key?(:language)
      {
        cyrillic: 1,
        latin: 2
      }[help_params[:language].to_sym] || 0
    end

    def base64_image
      @base64_image ||=
        File.open(image_path, 'rb') { |file| Base64.encode64(file.read) }
    end

    def start_request_params
      {
        body: base64_image,
        method: 'base64',
        phrase: phrase,
        regsense: register_sensitive,
        numeric: numeric,
        calc: calculation,
        language: language,
      }
    end
  end
end
